@@ -1,6 +1,12 @@
 import os
 from texta_mlp.utils import parse_bool_env
 
+
+META_KEY = "_mlp_meta"
+
+DEFAULT_DOC_PATH_KEY = "text"
+DEFAULT_OUTPUT_KEY = "text_mlp"
+
 # Languages supported by default.
 DEFAULT_LANG_CODES = ("et", "ru", "en", "ar")
 
